@@ -120,7 +120,7 @@ class TestGeneralUsage:
         result.stdout.fnmatch_lines([
             #XXX on jython this fails:  ">   import import_fails",
             "ImportError while importing test module*",
-            "'No module named *does_not_work*",
+            "*No module named *does_not_work*",
         ])
         assert result.ret == 2
 
