@@ -4,7 +4,8 @@ import py
 import os
 
 from _pytest.config import get_config, PytestPluginManager
-from _pytest.main import EXIT_NOTESTSCOLLECTED
+from _pytest.main import EXIT_NOTESTSCOLLECTED, Session
+
 
 @pytest.fixture
 def pytestpm():
@@ -83,6 +84,7 @@ class TestPytestPluginInteractions:
     def test_configure(self, testdir):
         config = testdir.parseconfig()
         l = []
+
         class A:
             def pytest_configure(self, config):
                 l.append(self)
@@ -102,13 +104,16 @@ class TestPytestPluginInteractions:
     def test_hook_tracing(self):
         pytestpm = get_config().pluginmanager  # fully initialized with plugins
         saveindent = []
+
         class api1:
             def pytest_plugin_registered(self):
                 saveindent.append(pytestpm.trace.root.indent)
+
         class api2:
             def pytest_plugin_registered(self):
                 saveindent.append(pytestpm.trace.root.indent)
                 raise ValueError()
+
         l = []
         pytestpm.trace.root.setwriter(l.append)
         undo = pytestpm.enable_tracing()
@@ -129,6 +134,25 @@ class TestPytestPluginInteractions:
         finally:
             undo()
 
+    def test_hook_proxy(self, testdir):
+        """Test the gethookproxy function(#2016)"""
+        config = testdir.parseconfig()
+        session = Session(config)
+        testdir.makepyfile(**{
+            'tests/conftest.py': '',
+            'tests/subdir/conftest.py': '',
+        })
+
+        conftest1 = testdir.tmpdir.join('tests/conftest.py')
+        conftest2 = testdir.tmpdir.join('tests/subdir/conftest.py')
+
+        config.pluginmanager._importconftest(conftest1)
+        ihook_a = session.gethookproxy(testdir.tmpdir.join('tests'))
+        assert ihook_a is not None
+        config.pluginmanager._importconftest(conftest2)
+        ihook_b = session.gethookproxy(testdir.tmpdir.join('tests'))
+        assert ihook_a is not ihook_b
+
     def test_warn_on_deprecated_multicall(self, pytestpm):
         warnings = []
 
