@@ -124,3 +124,10 @@ def test_inline_run_clean_modules(testdir):
     test_mod.write("def test_foo(): assert False")
     result2 = testdir.inline_run(str(test_mod))
     assert result2.ret == EXIT_TESTSFAILED
+
+def test_assert_outcomes_after_pytest_erro(testdir):
+    testdir.makepyfile("def test_foo(): assert True")
+
+    result = testdir.runpytest('--unexpected-argument')
+    with pytest.raises(ValueError, message="Pytest terminal report not found"):
+        result.assert_outcomes(passed=0)
